pub fn extract_functions(file: &SourceFile) -> Result<Vec<ExtractedFunction>>Expand description
Extract all functions from a source file using tree-sitter.
pub fn extract_functions(file: &SourceFile) -> Result<Vec<ExtractedFunction>>Extract all functions from a source file using tree-sitter.