Module test_mapper

Module test_mapper 

Structs

ScannedFiles
SourceFile

Functions

function_key
map_tests_to_functions
Map test functions to source functions they likely cover. Returns a set of source function identifiers that have test coverage.
scan_directory
Scan a directory for source and test files, respecting config excludes.