Structs
Functions
- function_
key - map_
tests_ to_ functions - Map test functions to source functions they likely cover. Returns a set of source function identifiers that have test coverage.
- scan_
directory - Scan a directory for source and test files, respecting config excludes.